==> do-translate-0.1.6.tgz: package/README.md <==
### About

[do-translate](https://www.npmjs.com/package/do-translate) is *npm* package for translating text samples via translation providers like *Google* and *Yandex*.

### Install

```bash
npm install do-translate
```

### Usage

Each *Translator* instance defines a bunch of public methods. Mostly, only
*Translator::lookup* method should be used to perform an actual translation.
*Translator::getLangs* and *Translator::translate* methods perform requests without
caching. *Translator::lookup* is expecting three params: *textToTranslate*, *langTo* and *langFrom*. Translation is performed asynchronously, result is immediately
resolved as [Promise](http://www.html5rocks.com/en/tutorials/es6/promises/) object.

```js
var Translator = require('do-translate').Translator;
```
Provider *alias* is passed to *Translator* upon creation along with API *key*
and *uri*.

### With NoopProvider for testing

```js
var noopTranslator = new Translator('noop');

noopTranslator.lookup('sample', 'ru', 'en')
    .then(function(result) {
        // "sample_en-ru" from request
        return noopTranslator.lookup('sample', 'ru', 'en');
    })
    .then(function(result) {
        // "sample_en-ru" from cache (should resolve faster)
    })
    .catch(function(error) {
        // debug error here
    })
;
```

### With Google Translate

```js
var googleTranslator = new Translator('google', 'google-key', 'google-uri');

googleTranslator.lookup('sample', 'ru', 'en')
    .then(function(result) {
        // "образец" from request
        return googleTranslator.lookup('sample', 'ru', 'en');
    })
    .then(function(result) {
        // "образец" from cache (should resolve faster)
    })
    .catch(function(error) {
        // debug error here
    })
;
```

### With Yandex Translate

```js
var yandexTranslator = new Translator('yandex', 'yandex-key', 'yandex-uri');

yandexTranslator.lookup('sample', 'ru', 'en')
    .then(function(result) {
        // "образец" from request
        return yandexTranslator.lookup('sample', 'ru', 'en');
    })
    .then(function(result) {
        // "образец" from cache (should resolve faster)
    })
    .catch(function(error) {
        // debug error here
    })
;
```

### Cache

Every response is cached. Cached value is returned if result for current request
is present locally. Note that to process translation, two requests at minimum
are to perform:
- Request supported languages
- Perfrom translation

### API errors

API errors, in general, like "translation failure", "api limit excess" are silent
and not reported in any form for now.

### Todo

- Browser version
- Add new provider lookup strategy (e.g. "web scrapping")
- Use native ES6 without transpiler.
- Use native *fetch* fn.
- Headless browser tests.

==> do-translate-0.1.8.tgz: package/README.md <==
### About

[do-translate](https://www.npmjs.com/package/do-translate) is *npm* package for translating text samples via translation providers like *Google* and *Yandex*. Browser version
is available as well.

### Todo
- Add new provider lookup strategy (e.g. "web scraping")
- Use native ES6 without transpiler.
- Use native *fetch* fn.
- Headless browser tests.

### Cache

Every response is cached. Cached value is returned if result for current request
is present locally. Note that to process translation, two requests at minimum
are to perform:
- Request supported languages
- Perfrom translation

### API errors

API errors, in general, like "translation failure", "api limit excess" are silent
and not reported in any form for now.

## Node

### Install

```bash
$ npm install do-translate
```

### Usage

*Translator* instance defines a bunch of methods. *Translator::lookup* is expecting
three params: *textToTranslate*, *langTo* and *langFrom*. Translation process is  asynchronous, result is immediately resolved as [Promise](http://www.html5rocks.com/en/tutorials/es6/promises/) object. Only
*Translator::lookup* should be used to for actual translation.
*Translator::getLangs* and *Translator::translate* methods perform requests without
caching.

```js
var Translator = require('do-translate').Translator;
```
Provider *alias* is passed to *Translator* upon creation along with API *key*
and *uri*.

### With NoopProvider for testing

```js
var noopTranslator = new Translator('noop');

noopTranslator.lookup('sample', 'ru', 'en')
    .then(function(result) {
        // "sample_en-ru" from request
        return noopTranslator.lookup('sample', 'ru', 'en');
    })
    .then(function(result) {
        // "sample_en-ru" from cache
    })
    .catch(function(error) {
        // debug error here
    })
;
```

### With Google Translate

```js
var googleTranslator = new Translator('google', 'google-key', 'google-uri');

googleTranslator.lookup('sample', 'ru', 'en')
    .then(function(result) {
        // "образец" from request
        return googleTranslator.lookup('sample', 'ru', 'en');
    })
    .then(function(result) {
        // "образец" from cache
    })
    .catch(function(error) {
        // debug error here
    })
;
```

### With Yandex Translate

```js
var yandexTranslator = new Translator('yandex', 'yandex-key', 'yandex-uri');

yandexTranslator.lookup('sample', 'ru', 'en')
    .then(function(result) {
        // "образец" from request
        return yandexTranslator.lookup('sample', 'ru', 'en');
    })
    .then(function(result) {
        // "образец" from cache
    })
    .catch(function(error) {
        // debug error here
    })
;
```

## Browser

Browser version is a result of transpiling/browserifing from ES6, hence must be
used with precaution.

### Install

```bash
$ bower install do-translate
```
Include required scripts

```html
<script src="./path/to/do-translate.js"></script>
```

Test with NoopProvider

```js
var Translator = doTranslate();
var noopTranslator = new Translator('noop');

noopTranslator.lookup('sample', 'ru', 'en')
    .then(function(result) {
        console.log(result); // "sample_en-ru" from request

        return noopTranslator.lookup('sample', 'ru', 'en');
    })
    .then(function(result) {
        console.log(result); // "sample_en-ru" from cache
    })
    .catch(function(error) {
        console.log(error); // debug error here
    })
;
```
